@@ -34,8 +34,7 @@
  *implementation
  ******************************************************************************/
 
-#ifndef ODSDOCHANDLERINTERFACE_H
-#define ODSDOCHANDLERINTERFACE_H
+#pragma once
 
 #include <QString>
 #include "reader/odscell.h"
@@ -81,4 +80,3 @@ class OdsDocHandlerInterface
   virtual void endDocument() = 0;
 };
 
-#endif // ODSDOCHANDLERINTERFACE_H
