@@ -19,7 +19,7 @@
 
 #pragma once
 
-#include <quazip5/quazip.h>
+#include <quazip.h>
 
 #include "reader/odscell.h"
 #include "odsdochandlerinterface.h"
