@@ -1,20 +1,18 @@
 
-#define CATCH_CONFIG_MAIN
-
-#ifdef CATCH2_MAJOR_VERSION_2
-#include <catch2/catch.hpp>
-#elif CATCH2_MAJOR_VERSION_3
-#include <catch2/catch_all.hpp>
-#endif
+#include <catch2/catch_test_macros.hpp>
 
 #include "config.h"
 #include <QDebug>
 #include <iostream>
+#include <odsstream/calcwriterinterface.h>
+#include <odsstream/odsdocwriter.h>
 #include <odsstream/odsdocreader.h>
 #include <odsstream/odsdocwriter.h>
 #include <odsstream/odsexception.h>
 #include <odsstream/writer/options/odscolorscale.h>
 #include <odsstream/writer/options/odstablecellstyle.h>
+#include "metadataodsreader.h"
+#include <QVariant>
 
 
 // make test ARGS="-V -I 1,1"
@@ -72,6 +70,7 @@ class CustomHandler : public OdsDocHandlerInterface
   virtual void endDocument() override{};
 };
 
+
 class CustomHandlerXic : public OdsDocHandlerInterface
 {
   public:
@@ -85,7 +84,10 @@ class CustomHandlerXic : public OdsDocHandlerInterface
   {
     m_columnNumber = 0;
     m_rowNumber    = 0;
-    if(sheet_name != "Feuille1")
+    if((sheet_name == "Feuille1") || (sheet_name == "metadata"))
+      {
+      }
+    else
       {
         throw OdsException(
           QObject::tr("sheet_name %1 != Feuille1").arg(sheet_name));
@@ -190,6 +192,34 @@ class CustomHandlerXic : public OdsDocHandlerInterface
 };
 
 
+TEST_CASE("Test ODS metadata bug files.", "[odsbug]")
+{
+  // Set the debugging message formatting pattern.
+  qSetMessagePattern(QString("%{file}@%{line}, %{function}(): %{message}"));
+
+  SECTION(
+    "reading "
+    "/gorgone/pappso/moulon/users/Olivier/20240131_proteobench/mcqr/"
+    "metadata_template.ods",
+    "[odsbug]")
+  {
+    cout << endl << "..:: Test ODS files ::.." << endl;
+
+    cout << endl
+         << "..:: read ODS file "
+            "metadata_template.ods ::.."
+         << endl;
+    MetadataOdsReader handler;
+    QFile xicfile(
+      QString(CMAKE_SOURCE_DIR).append("/test/data/metadata_template.ods"));
+    OdsDocReader xicfile_reader(handler);
+    REQUIRE_NOTHROW(xicfile_reader.parse(&xicfile));
+
+    xicfile.close();
+
+    cout << endl << "..:: read ODS file xic.ods is OK ::.." << endl;
+  }
+}
 TEST_CASE("Test ODS files.", "[ods]")
 {
   // Set the debugging message formatting pattern.
@@ -278,6 +308,9 @@ TEST_CASE("Test ODS files.", "[ods]")
     writer.setCellAnnotation("ceci est un commentaire n1");
     writer.writeCell("coucou");
 
+    QVariant var(28.753423424);
+    writer.writeCellVariant(var);
+
     QDateTime currentdate(QDateTime::currentDateTime());
 
     writer.setCellAnnotation("ceci est un commentaire sur une date");
